
Observatorio de gestión pública e inteligencia de mercados

El objetivo del mismo es proporcionar a la comunidad académica de la Facultad de Contaduría y Ciencias Administrativas, de la Universidad Michoacana de San Nicolás de Hidalgo y al público en general, información confiable, sistematizada y actualizada referente a los precios de mercado de granos, frutas y hortalizas.
